@@ -5,9 +5,10 @@
 
 prior <- function(phi, lambda=NULL, B=NULL, Z=NULL, gam=NULL, it=NULL, K=NULL, priortype="laplaceinhib") {
 	if(priortype=="laplace") {
-		EG <- -(abs(B - detailed.to.simple.regulations(phi))/lambda)
-		prefix <- -log(2) - log(lambda)
-		PGlambda <- sum(prefix + EG)
+		## if B only holds the information if there is an edge or not, then use laplace. if 
+		## additionally the type of edge is encoded in B, then use laplaceinhib
+		phi <- detailed.to.simple.regulations(phi)
+		PGlambda <- sum(-log(2) - log(lambda) + (-(abs(B - phi)^gam))/lambda)
 	} else if(priortype=="scalefree") {
 		PGlambda <- log(pgs(phi,gam,K,it))
 	} else if(priortype=="laplaceinhib") {
@@ -20,7 +21,7 @@ prior <- function(phi, lambda=NULL, B=NULL, Z=NULL, gam=NULL, it=NULL, K=NULL, p
 		if(is.null(gam))
 			gam <- 2
 		phi[phi==2] <- -1	
-		PGlambda <- sum(-log(2) - log(lambda) + (-abs(B - phi)^gam)/lambda)
+		PGlambda <- sum(-log(2) - log(lambda) + (-(abs(B - phi)^gam))/lambda)
 	}
 	PGlambda
 }
